Pindakaas
=========

**Encoding propositional and Pseudo Boolean constraints into CNF**

This documentation describes the Python interface to the Pindakaas Rust library.
See the `Rust documentation <https://crates.io/crates/pindakaas>`_ for more in-depth information.

*Acknowledgements.* This research was partially funded by the Australian Government through the Australian Research Council Industrial Transformation Training Centre in Optimisation Technologies, Integrated Methodologies, and Applications (OPTIMA), Project ID IC200100009.

.. The full API is described in the following section.

.. toctree::
   :maxdepth: 2

   getting_started
   api
  

